<?php
/**
 * pragmaMx - Web Content Management System.
 * Copyright by pragmaMx Developer Team - http://www.pragmamx.org
 *
 * $Revision: 499 $
 * $Author: PragmaMx $
 * $Date: 2022-05-11 14:15:10 +0200 (Mi, 11. Mai 2022) $
 */

/* diese Zeile nicht ändern!! */
defined('mxMainFileLoaded') or die('access denied');

/**
 * der Titel im Kopfbereich der Seite,
 * z.B.: 'pragmaMx'
 */
$themesetting['title'] = $GLOBALS['sitename'];

/**
 * der Untertitel/Slogan im Kopfbereich der Seite
 * z.B.: 'the fast CMS...'
 */
$themesetting['slogan'] = $GLOBALS['slogan'];

/**
 * Layout-Typ: fluid oder fixed
 */
$themesetting['layouttype'] = 'fixed';

/**
 * Anordnung der Layout-Spalten: default, left, right
 * .                               |-|     ||-   -||
 */
$themesetting['layoutcols'] = 'default';

/**
 * Breite der Layout-Spalten
 */
$themesetting['layoutwidth'] = array(/* Breiten */
    'min' => 780,/* minimale Seitenbreite, immer in Pixel! */
    'max' => 1200,/* maximale Seitenbreite, immer in Pixel! */
    /* wenn Typ = fluid eingestellt: */
    'page_fluid' => 100,/* Seitenbreite, Typ fluid, in Prozent */
    'left_fluid' => 21,/* linke Blockspalte, Typ fluid, in Prozent */
    'right_fluid' => 21,/* rechte Blockspalte, Typ fluid, in Prozent */
    /* wenn Typ = fixed eingestellt: */
    'page_fixed' => 960,/* Seitenbreite, Typ fixed, in Pixel */
    'left_fixed' => 207,/* linke Blockspalte, Typ fixed, in Pixel */
    'right_fixed' => 207,/* rechte Blockspalte, Typ fixed, in Pixel */
    );

/**
 * das Menü im Kopfbereich
 * - den Menünamen aus dem Menümanager angeben, oder
 * - leer lassen (false) um das weiter unten definierte Menü zu verwenden
 */
$themesetting['head_css_menu'] = false; // z.B.: {CSS-MENU}

/* folgendes nur, wenn Module geladen */
if (defined('MX_MODULE')) {
    /* Hilfsvariablen für das SMF-Forum */
    global $context; // vom SMF
    $current_action = isset($context['current_action']) ? $context['current_action'] : false;

    /**
     * Seiten, bei denen, die linken Blöcke nicht gezeigt werden sollen
     */
    $themesetting['hide-left'] = array(/* Seiten/Module */
        // MX_MODULE == 'Downloads',
        // MX_MODULE == 'FAQ',
        // MX_MODULE == 'Downloads' && $_REQUEST['cid'] == 61, // Downloads, Kategorie 61
        // $_REQUEST['name'] == 'Content' && $_REQUEST['pid'] == 28, // Contentmodul Id 28
        );

    /**
     * Seiten, bei denen beide Blockspalten nicht angezeigt werden sollen
     */
    $themesetting['hide-both'] = array(/* Seiten/Module */
        MX_MODULE == 'admin',
        MX_MODULE == 'Forum' && $current_action != 'profile' && $current_action != 'pm' ,
        MX_MODULE == 'eBoard',
        // weitere Beispiele:
        // MX_MODULE === 'Gallery',
        // MX_MODULE == 'Downloads' && $_REQUEST['cid'] == 61, // Downloads, Kategorie 61
        // $_REQUEST['name'] == 'Content' && $_REQUEST['pid'] == 28, // Contentmodul Id 28
        );

    /* folgendes nur, wenn kein Menü des Menümanagers verwendet werden soll */
    if (!$themesetting['head_css_menu']) {
        /**
         * die Navigationsbuttons im header, wird in der
         * Funktion theme_define_placeholders() ausgewertet
         */
        $themesetting['headnav'][] = array(/* Startseite */
            'menu' => 1,
            'caption' => _HOME,
            'link' => './',
            'case' => array(
                defined('MX_HOME_FILE'),
                ));

        $themesetting['headnav'][] = array(/* Newsmodul */
            'menu' => 1,
            'caption' => _NEWSSHORT,
            'link' => 'modules.php?name=Stories_Archive',
            'case' => array(
                MX_MODULE == 'Topics',
                MX_MODULE == 'News' && !defined('MX_HOME_FILE'),
                ));

        $themesetting['headnav'][] = array(/* Content */
            'menu' => 1,
            'caption' => _CONTENT,
            'link' => 'modules.php?name=Content',
            'case' => array(
                MX_MODULE == 'Content',
                ));

        $themesetting['headnav'][] = array(/* Suche */
            'menu' => 1,
            'caption' => _SEARCH,
            'link' => 'modules.php?name=Search',
            'case' => array(
                MX_MODULE == 'Search',
                ));

        $themesetting['headnav'][] = array(/* Impressum */
            'menu' => 1,
            'caption' => _IMPRESSUM,
            'link' => 'modules.php?name=Impressum',
            'case' => array(
                MX_MODULE == 'Impressum',
                MX_MODULE == 'legal',
                ));

        if (MX_IS_ADMIN) {
            $themesetting['headnav'][] = array(/* Administration */
                'menu' => 1,
                'caption' => _ADMINMENUEBL,
                'link' => adminUrl(),
                'case' => array(
                    MX_MODULE == 'admin',
                    ));
        }

        /* ------ ENDE Navigationsbuttons ------- */
    }
}
/* Ende nur Module */

/**
 * folgende Einstellungen sollten nicht verändert werden
 */

/* Modul-Blöcke im passenden Design anzeigen */
$themesetting['blocknav']['style'] = 'menu';
$themesetting['blocknav']['current'] = 'current';

/* definieren ob die Templates des Themes gecached werden können */
define('MX_THEME_CACHABLE', true);

/* Dateiname des templates */
define('MX_THIS_THEMEFILE', 'theme.html');

?>
